package sun.util.locale.provider;

import java.util.spi.LocaleServiceProvider;
import sun.util.calendar.ZoneInfo;
import java.util.Objects;
import java.util.Iterator;
import java.util.Set;
import java.util.LinkedList;
import java.util.spi.TimeZoneNameProvider;
import java.util.Map;
import java.lang.ref.SoftReference;
import java.util.Locale;
import java.util.concurrent.ConcurrentHashMap;

public final class TimeZoneNameUtility
{
    private static ConcurrentHashMap<Locale, SoftReference<String[][]>> cachedZoneData;
    private static final Map<String, SoftReference<Map<Locale, String[]>>> cachedDisplayNames;
    
    public static String[][] getZoneStrings(Locale locale) {
        SoftReference<Object> softReference = (SoftReference)TimeZoneNameUtility.cachedZoneData.get(locale);
        String[][] loadZoneStrings;
        if (softReference == null || (loadZoneStrings = (String[][])softReference.get()) == null) {
            loadZoneStrings = loadZoneStrings(locale);
            TimeZoneNameUtility.cachedZoneData.put(locale, new SoftReference(loadZoneStrings));
            return loadZoneStrings;
        }
        return loadZoneStrings;
    }
    
    private static String[][] loadZoneStrings(Locale locale) {
        TimeZoneNameProvider timeZoneNameProvider = LocaleProviderAdapter.getAdapter(TimeZoneNameProvider.class, locale).getTimeZoneNameProvider();
        if ((timeZoneNameProvider instanceof TimeZoneNameProviderImpl)) {
            return ((TimeZoneNameProviderImpl)timeZoneNameProvider).getZoneStrings(locale);
        }
        Set<String> zoneIDs = LocaleProviderAdapter.forJRE().getLocaleResources(locale).getZoneIDs();
        LinkedList<String> list = new LinkedList();
        Iterator<Object> iterator = zoneIDs.iterator();
        while (iterator.hasNext()) {
            String[] retrieveDisplayNamesImpl = retrieveDisplayNamesImpl((String)iterator.next(), locale);
            if (retrieveDisplayNamesImpl != null) {
                list.add(retrieveDisplayNamesImpl);
            }
            else {
                continue;
            }
        }
        return (String[][])list.toArray(new String[list.size()][]);
    }
    
    public static String[] retrieveDisplayNames(String obj, Locale obj2) {
        Objects.requireNonNull(obj);
        Objects.requireNonNull(obj2);
        return retrieveDisplayNamesImpl(obj, obj2);
    }
    
    public static String retrieveGenericDisplayName(String s, int n, Locale locale) {
        String[] retrieveDisplayNamesImpl = retrieveDisplayNamesImpl(s, locale);
        if (Objects.nonNull(retrieveDisplayNamesImpl)) {
            return retrieveDisplayNamesImpl[6 - n];
        }
        return null;
    }
    
    public static String retrieveDisplayName(String s, boolean b, int n, Locale locale) {
        String[] retrieveDisplayNamesImpl = retrieveDisplayNamesImpl(s, locale);
        if (Objects.nonNull(retrieveDisplayNamesImpl)) {
            return retrieveDisplayNamesImpl[(b ? 4 : 2) - n];
        }
        return null;
    }
    
    private static String[] retrieveDisplayNamesImpl(String s, Locale locale) {
        LocaleServiceProviderPool pool = LocaleServiceProviderPool.getPool(TimeZoneNameProvider.class);
        Object referent = null;
        SoftReference<Object> obj = (SoftReference)TimeZoneNameUtility.cachedDisplayNames.get(s);
        if (Objects.nonNull(obj)) {
            referent = (Object)obj.get();
            if (Objects.nonNull(referent)) {
                String[] obj2 = (String[])referent.get(locale);
                if (Objects.nonNull(obj2)) {
                    return obj2;
                }
            }
        }
        String[] array = new String[7];
        array[0] = s;
        for (int i = 1; i <= 6; ++i) {
            array[i] = (String)pool.getLocalizedObject(TimeZoneNameUtility.TimeZoneNameGetter.INSTANCE, locale, (i < 5) ? ((i < 3) ? "std" : "dst") : "generic", new Object[] { Integer.valueOf(i % 2), s });
        }
        if (Objects.isNull(referent)) {
            referent = new ConcurrentHashMap();
        }
        referent.put(locale, array);
        TimeZoneNameUtility.cachedDisplayNames.put(s, new SoftReference(referent));
        return array;
    }
    
    private TimeZoneNameUtility() {
    }
    
    static {
        TimeZoneNameUtility.cachedZoneData = new ConcurrentHashMap();
        cachedDisplayNames = new ConcurrentHashMap();
    }
    
    private static class TimeZoneNameGetter implements LocaleServiceProviderPool.LocalizedObjectGetter<TimeZoneNameProvider, String>
    {
        private static final TimeZoneNameUtility.TimeZoneNameGetter INSTANCE;
        
        @Override
        public String getObject(TimeZoneNameProvider timeZoneNameProvider, Locale locale, String s, Object... array) {
            assert array.length == 2;
            int intValue = (int)array[0];
            String s2 = (String)array[1];
            String s3 = getName(timeZoneNameProvider, locale, s, intValue, s2);
            if (s3 == null) {
                Map<String, String> aliasTable = ZoneInfo.getAliasTable();
                if (aliasTable != null) {
                    String s4 = (String)aliasTable.get(s2);
                    if (s4 != null) {
                        s3 = getName(timeZoneNameProvider, locale, s, intValue, s4);
                    }
                    if (s3 == null) {
                        s3 = examineAliases(timeZoneNameProvider, locale, s, (s4 != null) ? s4 : s2, intValue, aliasTable);
                    }
                }
            }
            return s3;
        }
        
        private static String examineAliases(TimeZoneNameProvider timeZoneNameProvider, Locale locale, String s, String anObject, int n, Map<String, String> map) {
            for (Map.Entry entry : map.entrySet()) {
                if (((String)entry.getValue()).equals(anObject)) {
                    String s2 = (String)entry.getKey();
                    String name = getName(timeZoneNameProvider, locale, s, n, s2);
                    if (name != null) {
                        return name;
                    }
                    String examineAliases = examineAliases(timeZoneNameProvider, locale, s, s2, n, map);
                    if (examineAliases != null) {
                        return examineAliases;
                    }
                    continue;
                }
                else {
                    continue;
                }
            }
            return null;
        }
        
        private static String getName(TimeZoneNameProvider timeZoneNameProvider, Locale locale, String s, int style, String id) {
            String s2 = null;
            int n = -1;
            switch (s.hashCode()) {
                case 114211: {
                    if (s.equals("std")) {
                        n = 0;
                        break;
                    }
                    break;
                }
                case 99781: {
                    if (s.equals("dst")) {
                        n = 1;
                        break;
                    }
                    break;
                }
                case -80148009: {
                    if (s.equals("generic")) {
                        n = 2;
                        break;
                    }
                    break;
                }
            }
            switch (n) {
                case 0: {
                    s2 = timeZoneNameProvider.getDisplayName(id, false, style, locale);
                    break;
                }
                case 1: {
                    s2 = timeZoneNameProvider.getDisplayName(id, true, style, locale);
                    break;
                }
                case 2: {
                    s2 = timeZoneNameProvider.getGenericDisplayName(id, style, locale);
                    break;
                }
            }
            return s2;
        }
        
        static {
            INSTANCE = new TimeZoneNameUtility.TimeZoneNameGetter();
        }
    }
}
